package com.yixin.ms.api.domain.dto;

import com.alibaba.fastjson.annotation.JSONField;
import com.yixin.ms.api.constant.RemoteResidencePermitDict;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;

/**
 * @description: LiveRegisterReportDTO <br>
 * @date: 2022/9/7 9:04 <br>
 * @author: WXG <br>
 */
@Data
public class LiveRegisterReportDTO {
    /**
     * F32 上报数据包编号[区别本次居住登记 上报的唯一标识]
     */
    @ApiModelProperty("上报数据包编号[区别本次居住登记 上报的唯一标识]")
    @JSONField(name = "opid")
    private String opid;
    /**
     * F18 流动人口身份证号
     */
    @ApiModelProperty("流动人口身份证号")
    @NotBlank(message = "流动人口身份证号不能为空")
    @Pattern(regexp = "^(\\d{18,18}|\\d{15,15}|(\\d{17,17}[x|X]))$", message = "身份证格式错误")
    @JSONField(name = "idcard")
    private String idCard;
    /**
     * V30 流动人口姓名
     */
    @ApiModelProperty("流动人口姓名")
    @NotBlank(message = "流动人口姓名不能为空")
    @Length(message = "最大长度30", max = 30)
    @JSONField(name = "name")
    private String name;
    /**
     * F1 性别，1 男 2 女
     */
    @ApiModelProperty("性别，1 男 2 女")
    @NotBlank(message = "性别不能为空")
    @Length(message = "最大长度1", max = 30)
    @JSONField(name = "sex")
    private String sex;
    /**
     * F2 民族，参考代码表
     */
    @ApiModelProperty("民族，参考代码表")
    @NotBlank(message = "名族不能为空")
    @Length(message = "名族格式错误", min = 2, max = 2)
    @JSONField(name = "nation")
    private String nation;
    /**
     * F8 出生日期，yyyymmdd 格式
     */
    @ApiModelProperty("出生日期，yyyymmdd 格式")
    @NotBlank(message = "出生日期不能为空")
    @Length(message = "出生日期格式错误", min = 8, max = 8)
    @JSONField(name = "birthday")
    private String birthday;
    /**
     * V11 联系电话
     */
    @ApiModelProperty("联系电话")
    @NotBlank(message = "联系电话不能为空")
    @Length(message = "最大长度11", max = 11)
    @JSONField(name = "phone")
    private String phone;
    /**
     * V6 户口省县，身份证号前 6 位
     */
    @ApiModelProperty("户口省县，身份证号前 6 位")
    @NotBlank(message = "户口省县(身份证号前6位)不能为空")
    @Length(message = "最大长度6", max = 6)
    @JSONField(name = "domicile_city")
    private String domicileCity;
    /**
     * V33 户口详址
     */
    @ApiModelProperty("户口详址")
    @Length(message = "最大长度33", max = 33)
    @JSONField(name = "domicile_addr")
    private String domicileAddr;
    /**
     * V20 出租房屋档案号，DB33 编码
     */
    @ApiModelProperty("出租房屋档案号，DB33 编码")
    @Length(message = "最大长度20", max = 20)
    @JSONField(name = "house_no")
    private String houseNo;
    /**
     * V50 小区名（居住详址，不含省县区）
     */
    @ApiModelProperty("小区名（居住详址，不含省县区）")
    @NotBlank(message = "小区名（居住详址，不含省县区）不能为空")
    @Length(message = "最大长度50", max = 50)
    @JSONField(name = "community")
    private String community;
    /**
     * V32 幢号
     */
    @ApiModelProperty("幢号")
    @Length(message = "最大长度32", max = 32)
    @JSONField(name = "build")
    private String build;
    /**
     * V32 单元号
     */
    @ApiModelProperty("单元号")
    @Length(message = "最大长度32", max = 32)
    @JSONField(name = "unit")
    private String unit;
    /**
     * V20 房号
     */
    @ApiModelProperty("房号")
    @Length(message = "最大长度20", max = 20)
    @NotBlank(message = "房号不能为空")
    @JSONField(name = "room_no")
    private String roomNo;
    /**
     * V13 居住地辖区，参考代码表“社区村”
     */
    @ApiModelProperty(value = "居住地辖区，参考代码表“社区村”", required = true)
    @Length(message = "最大长度13", max = 13)
    @NotBlank(message = "居住地辖区不能为空")
    @JSONField(name = "region")
    private String region;
    /**
     * V15 房东姓名
     */
    @ApiModelProperty("房东姓名")
    @NotBlank(message = "房东姓名不能为空")
    @Length(message = "最大长度15", max = 15)
    @JSONField(name = "landlord_name")
    private String landlordName;
    /**
     * F18 房东身份证号
     */
    @ApiModelProperty("房东身份证号")
    @JSONField(name = "landlord_idcard")
    private String landlordIdCard;
    /**
     * V20 房东联系电话
     */
    @ApiModelProperty("房东联系电话")
    @NotBlank(message = "房东电话不能为空")
    @JSONField(name = "landlord_phone")
    private String landlordPhone;
    /**
     * V33 单位名称
     */
    @ApiModelProperty("单位名称")
    @JSONField(name = "company")
    private String company;
    /**
     * V30 单位联系电话
     */
    @ApiModelProperty("单位联系电话")
    @JSONField(name = "company_tel")
    private String companyTel;
    /**
     * V33 单位详细地址
     */
    @ApiModelProperty("单位详细地址")
    @JSONField(name = "company_addr")
    private String companyAddr;
    /**
     * F1 注销标志，参考代码表
     */
    @ApiModelProperty("注销标志，参考代码表")
    @JSONField(name = "cancel_flag")
    private String cancelFlag;
    /**
     * F14 注销时间，yyyymmddhhmmss 格式
     */
    @ApiModelProperty("注销时间，yyyymmddhhmmss 格式")
    @JSONField(name = "cancel_time")
    private String cancelTime;
    /**
     * F8 启租日期，yyyymmdd 格式TZ/T XXXXX—2018 8
     */
    @ApiModelProperty("启租日期，yyyymmdd 格式TZ/T XXXXX—2018 8")
    @JSONField(name = "start_date")
    private String startDate;
    /**
     * F8 停租日期，yyyymmdd 格式
     */
    @ApiModelProperty("停租日期，yyyymmdd 格式")
    @JSONField(name = "stop_date")
    private String stopDate;
    /**
     * V+ 人像照片 Base64 编码，200k 以内
     */
    @ApiModelProperty("+ 人像照片 Base64 编码，200k 以内")
    @NotBlank(message = "人像照片（Base64）不能为空")
    @JSONField(name = "face_image")
    private String faceImage;
    /**
     * V+身份证照片 Base64 编码，200k 以 内
     */
    @ApiModelProperty("+身份证照片 Base64 编码，200k 以 内")
    @NotBlank(message = "身份证照片不能为空")
    @JSONField(name = "idcard_image")
    private String idCardImage;
    /**
     * V2 居住事由，参考代码表
     */
    @ApiModelProperty("居住事由，参考代码表")
    @NotNull(message = "居住事由不能为空")
    @JSONField(name = "liveCode")
    private String liveCode;
    /**
     * V2 文化程度，参考代码表
     */
    @ApiModelProperty("文化程度，参考代码表")
    @NotNull(message = "文化程度不能为空")
    @JSONField(name = "eduCode")
    private String eduCode;
    /**
     * V2 婚姻状况，参考代码表
     */
    @ApiModelProperty("婚姻状况，参考代码表")
    @NotNull(message = "婚姻状况不能为空")
    @JSONField(name = "marCode")
    private String marCode;
    /**
     * V2 政治面貌，参考代码表
     */
    @ApiModelProperty("政治面貌，参考代码表")
    @NotNull(message = "政治面貌不能为空")
    @JSONField(name = "politicalCode")
    private String politicalCode;
    /**
     * V2 从事职业，参考代码表
     */
    @ApiModelProperty("从事职业，参考代码表")
    @NotNull(message = "从事职业")
    @JSONField(name = "jobCode")
    private String jobCode;
    /**
     * V2 居住处所，参考代码表
     */
    @ApiModelProperty("居住处所，参考代码表")
    @NotNull(message = "居住处所不能为空")
    @JSONField(name = "zzcs")
    private String zzcs;
    /**
     * V30 单位负责人
     */
    @ApiModelProperty("单位负责人")
    @JSONField(name = "dwfzr")
    private String dwfzr;
    /**
     * F1 劳动合同签订情况 0 无 1 有
     */
    @ApiModelProperty("劳动合同签订情况 0 无 1 有")
    @JSONField(name = "ldhtqk")
    private String ldhtqk;
    /**
     * F1 养老保险 0 无 1 有
     */
    @ApiModelProperty("养老保险 0 无 1 有")
    @JSONField(name = "ylbx")
    private String ylbx;
    /**
     * F1 医疗保险 0 无 1 有
     */
    @ApiModelProperty("医疗保险 0 无 1 有")
    @JSONField(name = "yilbx")
    private String yilbx;
    /**
     * F1 失业保险 0 无 1 有
     */
    @ApiModelProperty("失业保险 0 无 1 有")
    @JSONField(name = "sybx")
    private String sybx;
    /**
     * F1 工伤保险 0 无 1 有
     */
    @ApiModelProperty("工伤保险 0 无 1 有")
    @JSONField(name = "gsbx")
    private String gsbx;
    /**
     * F1 生育保险 0 无 1 有
     */
    @ApiModelProperty("生育保险 0 无 1 有")
    @JSONField(name = "syubx")
    private String syubx;
    /**
     * V30 申报人的设备网络 ip
     */
    @ApiModelProperty("申报人的设备网络 ip")
    @JSONField(name = "cjrip")
    private String cjrip;
    /**
     * V40 申报人名称【操作员姓名】
     */
    @ApiModelProperty("申报人名称【操作员姓名】")
    @JSONField(name = "cjr")
    private String cjr;

}
