package com.yixin.ms.service.impl;

import cn.hutool.cache.CacheUtil;
import cn.hutool.cache.impl.TimedCache;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.yixin.ms.api.RemoteResidencePermitApi;
import com.yixin.ms.api.domain.BaseResidencePermitWrapper;
import com.yixin.ms.api.domain.dto.LiveRegisterReportDTO;
import com.yixin.ms.api.domain.dto.ResidencePermitTokenDTO;
import com.yixin.ms.api.domain.vo.LiveRegisterReportVO;
import com.yixin.ms.api.domain.vo.ResidencePermitTokenVO;
import com.yixin.ms.api.util.DESUtil;
import com.yixin.ms.service.ResidencePermitService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.Map;

/**
 * @description: ResidencePermitServiceImpl <br>
 * @date: 2022/9/6 16:48 <br>
 * @author: WXG <br>
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class ResidencePermitServiceImpl implements ResidencePermitService {

    /**
     * 服务对象
     */
    private final RemoteResidencePermitApi remoteResidencePermitApi;

    @Value("${residence_permit.appid}")
    private String residencePermitAppid;

    @Value("${residence_permit.secret}")
    private String residencePermitSecret;

    @Value("${residence_permit.desSecret}")
    private String residencePermitDesSecret;

    /**
     * 请求密钥有效时间为 7200s 15次上限， 取7000，防止边界问题
     *
     * @see <a href="https://www.hutool.cn/docs/#/cache/TimedCache">定时缓存</a>
     */
    private static TimedCache<String, String> tokenCache = CacheUtil.newTimedCache(7000 * 1000);

    private String getToken() {
        String accessToken = tokenCache.get("token");
        if (StrUtil.isBlank(accessToken)) {
            BaseResidencePermitWrapper<ResidencePermitTokenDTO> tokenDTO = new BaseResidencePermitWrapper<ResidencePermitTokenDTO>
                    (new ResidencePermitTokenDTO(residencePermitAppid, residencePermitSecret));
            BaseResidencePermitWrapper<ResidencePermitTokenVO> tokenResult = remoteResidencePermitApi.getToken(tokenDTO);
            ResidencePermitTokenVO lastTokenVO = tokenResult.valid();
            accessToken = lastTokenVO.getToken();
            tokenCache.put("token", accessToken);
        }
        return accessToken;
    }

    @Override
    public LiveRegisterReportVO liveRegisterReport(LiveRegisterReportDTO liveRegisterReportDTO) {
        String accessToken = getToken();
        // 给定opid默认值
        liveRegisterReportDTO.setOpid(RandomUtil.randomString(32));
        String jsStr = JSONObject.toJSONString(liveRegisterReportDTO);
        System.out.println(jsStr);
        String payload = DESUtil.encrypt(jsStr, residencePermitDesSecret);
        log.info("\r\n流调人口信息上报加密串：{} \r\n加密对象：{}", payload, jsStr);
        BaseResidencePermitWrapper<String> liveRegisterReportDTOWrapper =
                new BaseResidencePermitWrapper<String>(accessToken, payload);

        BaseResidencePermitWrapper<Object> liveRegisterReportVOWrapper =
                remoteResidencePermitApi.liveRegisterReport(liveRegisterReportDTOWrapper);
        System.out.println(liveRegisterReportVOWrapper.valid());
        return null;
    }

    private void valid(Map<String, String> header) {
        if (!"00".equals(header.get("rspCode"))) {
            throw new RuntimeException(header.get("rspMessage"));
        }
    }
}
